# UserMetrics

User metrics

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**email** | **str** | User&#39;s email-address; Is an empty string if no email is found in the user id lookup | [optional] 
**count** | **int** | Number of intervals for which the user was active | [optional] 
**user_id** | **str** | Identifier for the active user | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


